@@ -141,7 +141,7 @@ def log_der0(*args):
     #except TypeError:
     #    return 1/args[0]/math.log(args[1])  # 2-argument form
 
-_erf_coef = 2/math.sqrt(math.pi)  # Optimization for erf()
+erf_coef = 2/math.sqrt(math.pi)  # Optimization for erf()
 
 fixed_derivatives = {
     # In alphabetical order, here:
@@ -159,8 +159,8 @@ fixed_derivatives = {
     'cos': [lambda x: -math.sin(x)],
     'cosh': [math.sinh],
     'degrees': [lambda x: math.degrees(1)],
-    'erf': [lambda x: exp(-x**2)*_erf_coef],
-    'erfc': [lambda x: -exp(-x**2)*_erf_coef],
+    'erf': [lambda x: exp(-x**2)*erf_coef],
+    'erfc': [lambda x: -exp(-x**2)*erf_coef],
     'exp': [math.exp],
     'expm1': [math.exp],
     'fabs': [lambda x: 1 if x >= 0 else -1],
